@@ -8,11 +8,7 @@ rm -f awf-gtk2 awf-gtk3 awf-gtk4
 
 # copy to a tmp directory
 mkdir builder builder/src
-touch builder/ChangeLog
-touch builder/NEWS
-touch builder/AUTHORS
-touch builder/README
-cp /usr/share/common-licenses/GPL-3 builder/COPYING
+cp /usr/share/common-licenses/GPL*3 builder/LICENSE
 cp configure.ac    builder/
 cp Makefile.am     builder/
 cp src/Makefile.am builder/src/
@@ -20,7 +16,7 @@ cp src/awf.c       builder/src/
 
 # build
 cd builder/
-autoreconf -f -i
+autoreconf -fi
 ./configure
 make -s
 
